@@ -774,11 +774,11 @@ __END__
 
 =head1 NAME
 
-Ascii::Text::Font::Chunky - The great new Ascii::Text::Font::Chunky!
+Ascii::Text::Font::Chunky - Chunky font
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
 =cut
 
